// STEP 1
/**
 * Plugin factory function. This function is called when 
 * akamai.amp.AMP.create is called and the config object 
 * contains the plugin's key.
 *
 * @param {Player} player
 *    The AMP instance.
 *
 * @param {Object} config
 *    The plugin configuration object
 *
 * @param {String} key
 *    The key used to register the plugin
 *
 * @returns {Promise<Object>}
*/
function createSamplePlugin(player, config, key) {
  return new Promise(function (resolve, reject) {
    console.log("Creating Sample Plugin", player, config, key);
    
    var plugin = {
      player: player,
      config: config,
      testing: function () {
        console.log("Sample Plugin Public API Function: " + this.config.testing);
      }
    };
    
    // player.loadResources can be used to load an array of js and css resources, see player.config.resources for an example
    // player.request can be used to load other http resources
    
    // or synchronously fulfill the promise
    if (true) {
      resolve(plugin);
    } else {
      reject("An error occured creating the " + key + " plugin.");
    }
  });
}

// STEP 2
/**
 * Registers a plugin factory function. This function is 
 * called when akamai.amp.AMP.create is called and the 
 * config object contains the plugin's key.
 *
 * @param {String} key
 *    The plugin's key. Used to configure the plugin.
 *
 * @param {Function} factory
 *    The factory function used to create plugin.
 *
 * @param {String|Array.<String>} [mode=["html", "flash"]]
 *    Optional player mode(s) in which the plugin can be used.
*/
akamai.amp.AMP.registerPlugin("sample", createSamplePlugin, ["html", "flash"]);
